"use strict";
var __spreadArray = (this && this.__spreadArray) || function (to, from) {
    for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)
        to[j] = from[i];
    return to;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createMetadataExtractor = exports.loadFile = exports.isYml = exports.isVid = exports.isPdf = exports.isImg = exports.getFilePath = exports.getExt = exports.getFilename = void 0;
var url_1 = require("url");
var fs_extra_1 = __importDefault(require("fs-extra"));
var path_1 = __importDefault(require("path"));
function getFilename(str) {
    if (str === void 0) { str = ''; }
    if (!str.includes('/'))
        return str;
    return str.substring(str.lastIndexOf('/') + 1);
}
exports.getFilename = getFilename;
function getExt(str) {
    return str.includes('.') ? str.substring(str.lastIndexOf('.') + 1) : '';
}
exports.getExt = getExt;
function getFilePath() {
    var paths = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        paths[_i] = arguments[_i];
    }
    return path_1.default.normalize(path_1.default.resolve(path_1.default.join.apply(path_1.default, __spreadArray([process.cwd()], paths))));
}
exports.getFilePath = getFilePath;
function isImg(s) {
    return /([a-z\-_0-9\/\:\.]*\.(jpg|jpeg|png|gif|bmp|tif))/i.test(s);
}
exports.isImg = isImg;
function isPdf(s) {
    return s.endsWith('.pdf');
}
exports.isPdf = isPdf;
function isVid(s) {
    return /([a-z\-_0-9\/\:\.]*\.(mp4|avi|wmv))/i.test(s);
}
exports.isVid = isVid;
function isYml(s) {
    return s.endsWith('.yml');
}
exports.isYml = isYml;
function loadFile(filepath) {
    return fs_extra_1.default.readFileSync(filepath, 'utf8');
}
exports.loadFile = loadFile;
/** @param { 'filepath' | 'link' } type */
function createMetadataExtractor(type) {
    // type GetMetadataObjectArgsObject = Partial<{ [K in typeof type]: string }> & {
    // 	baseUrl?: string
    // 	prefix?: string
    // 	tilde?: string
    // }
    function getMetadataObject(s) {
        var metadata = {};
        var value = typeof s === 'string' ? s : s[type];
        metadata.raw = value;
        metadata.ext = getExt(value);
        metadata.filename = getFilename(value);
        if (value.startsWith('http')) {
            var url = new url_1.URL(value);
            metadata.pathname = url.pathname;
        }
        else {
            metadata.pathname = value.startsWith('/') ? value : "/" + value;
        }
        if (typeof s === 'string') {
            if (type === 'link') {
                if (value.startsWith('http'))
                    metadata.link = value;
                // The link is a pathname, so we need to construct the protocol/hostname
                // TODO - Find a way to get the hostname here?
                else
                    metadata.link = value;
            }
            else {
                metadata.filepath = getFilePath(value);
            }
        }
        else {
            if (type === 'link') {
                var _a = s.baseUrl, baseUrl = _a === void 0 ? '' : _a, _b = s.prefix, prefix = _b === void 0 ? '' : _b;
                metadata.link = baseUrl;
                prefix && (metadata.link += "" + prefix);
                metadata.link += metadata.pathname.startsWith('/')
                    ? metadata.pathname
                    : "/" + metadata.pathname;
            }
            else {
                metadata.filepath = s.prefix
                    ? getFilePath(path_1.default.join(s.prefix, s[type]))
                    : getFilePath(s[type]);
            }
        }
        if (isImg(value)) {
            metadata.group = 'images';
        }
        else if (isPdf(value)) {
            metadata.group = 'documents';
        }
        else if (isVid(value)) {
            metadata.group = 'videos';
        }
        else if (value.endsWith('.html') || value.endsWith('.js')) {
            metadata.group = 'scripts';
        }
        return metadata;
    }
    return getMetadataObject;
}
exports.createMetadataExtractor = createMetadataExtractor;
//# sourceMappingURL=utils.js.map